/**
 *    @file
 *
 *    @section LICENSE
 *
 *    Copyright 2009 Bayer & Szell OEG
 *
 *    This file is part of secrond.
 *
 *    secrond is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    secrond is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with secrond.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    @section DESCRIPTION
 *
 *    Header File @n
 *    Contains functions to implement typical daemon features.
 */

 
#ifndef DAEMON_H
#define	DAEMON_H


#include "secrond.h"


/**
 * Recursive implementation of @c mkdir().
 *
 * @param path Directory path to be created.
 * @param mode File permissions of the new directories.
 *
 * @retval TRUE  No problems were encountered. Existing directories are ignored.
 * @retval FALSE A directory could not be created.
 */
Boolean mkdirRecursive(char *path, mode_t mode);


/**
 * Writes debug information or program output to a log file.
 *
 * @param doExit   Whether to @c exit(1) after writing the log.
 * @param noHeader Whether to include header information (date and time).
 * @param progName Name of the program the output is from, if any.
 * @param argSize  Amount of bytes to allocate for args in @a format.
 * @param format   String that is passed to @c vsprintf.
 * @param ...      Any additional arguments for @c vsprintf.
 */
void writeLog(Boolean doExit, Boolean noHeader, char *progName, int argSize, char *format, ...);


/**
 * Makes this process a daemon.
 *
 */
void daemonize();


/**
 * Makes sure only one instance can be run.
 *
 */
void singleInstance();


/**
 * Handler for signals, quitting.
 *
 * @param s Signal that has been received.
 */
void handleSignalQuit(int s);


/**
 * Handler for @e SIGUSR1 signal, setting reloadSchedule to @c TRUE.
 *
 * @param s Signal that has been received.
 */
void handleSignalUser(int s);


/**
 * Sets up user functions as signal handlers.
 *
 */
void handleSignals();


/**
 * Handler for signals received by the child, quitting.
 *
 * @param s Signal that has been received.
 */
void handleSignalQuitChild(int s);


/**
 * Sets up user functions as signal handlers for the child.
 *
 */
void handleSignalsChild();


#endif
