/**
 *    @file
 *
 *    @section LICENSE
 *
 *    Copyright 2009 Bayer & Szell OEG
 *
 *    This file is part of secrond.
 *
 *    secrond is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    secrond is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with secrond.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    @section DESCRIPTION
 *
 *    Header File @n
 *    Manages the schedule and knows when commands need to be executed.
 */

 
#ifndef SECROND_H
#define	SECROND_H


#include <stdio.h>
#include <stdlib.h>
#include <signal.h>
#include <unistd.h>
#include <time.h>
#include <stdarg.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <errno.h>


#include "bitstring.h"


#include "macros.h"
#include "structs.h"
#include "strings.h"
#include "daemon.h"
#include "execute.h"
#include "parse.h"


#if WITH_DMALLOC
#  include <dmalloc.h>
#endif


/** Linked list of the schedule. */
extern SchedEntryDb *schedule;
/** Set to @c TRUE whenever the schedule has to be reloaded from the disk. */
extern Boolean reloadSchedule;
/** Stores process ID, remains open and locked in main process. */
extern FILE *lockFile;


/**
 * Clears the schedule of all its entries.
 *
 * @param freeDbStructure Whether to unallocate memory for schedule.
 */
void freeDb(Boolean freeDbStructure);


/**
 * Removes the lock file and calls freeDb, called at exit.
 *
 */
void freeResources();


#endif
