/**
 *    @file
 *
 *    @section LICENSE
 *
 *    Copyright 2009 Bayer & Szell OEG
 *
 *    This file is part of secrond.
 *
 *    secrond is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    secrond is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with secrond.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    @section DESCRIPTION
 *
 *    Header File @n
 *    Includes an implementation of strlen and other string manipulation
 *    functions.
 */

 
#ifndef STRINGS_H
#define	STRINGS_H


/**
 * Implementation of @c strlen.
 *
 * @param str Scanned for the first @c null character.
 *
 * @return The amount of characters before the first @c null character.
 */
extern inline int my_strlen(const char *str);


/**
 * Finds the first occurrence of @a c.
 *
 * @param str Scanned for the first @a c character.
 * @param c   Character to search @a str for.
 *
 * @return Location of the first @a c character, or -1 if not found.
 */
extern inline int charpos(const char *str, const char c);


/**
 * Moves the @c pointer past any tabs and spaces.
 *
 * @param str @c Pointer to be moved.
 *
 * @return A @c pointer to a non-whitespace character.
 */
extern inline char * skipWhitespace(char *str);


/**
 * Copies any non-whitespace characters to @a dest and moves the @c pointer past them.
 *
 * @param str  @c Pointer to be scanned and moved.
 * @param max  Maximum amount of characters @a dest can hold.
 * @param dest Destination non-whitespace characters of @a str are copied to.
 *
 * @return The processed @a str @c pointer pointing behind the last non-whitespace.
 */
extern inline char * extractNonWhitespace(char *str, int max, char *dest);


/**
 * Removes newlines and whitespace characters at the end of @a str.
 *
 * @param str String to be processed.
 */
extern inline void removeTrailingWhitespace(char * str);


#endif
