/**
 *    @file
 *
 *    @section LICENSE
 *
 *    Copyright 2009 Bayer & Szell OEG
 *
 *    This file is part of secrond.
 *
 *    secrond is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    secrond is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with secrond.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    @section DESCRIPTION
 *
 *    Defines all used structs.
 */

 
#ifndef STRUCTS_H
#define	STRUCTS_H


/** Structure that holds an entry of the schedule. */
struct _SchedEntry {
    /** Reference to the next SchedEntry structure. */
    struct _SchedEntry      *next;
    /** Seconds in which the command would be executed. */
    bitstr_t                bit_decl(sec, SEC_MAX - SEC_MIN + 1);
    /** Minutes in which the command would be executed. */
    bitstr_t                bit_decl(min, MIN_MAX - MIN_MIN + 1);
    /** Hours in which the command would be executed. */
    bitstr_t                bit_decl(hour, HOUR_MAX - HOUR_MIN + 1);
    /** Days of the month in which the command would be executed. */
    bitstr_t                bit_decl(mday, MDAY_MAX - MDAY_MIN + 1);
    /** Command to execute. */
    char                    *execCmd;
};


/** Creates a typename for _SchedEntry. */
typedef struct _SchedEntry SchedEntry;


/** Structure that has references to the start and end of entries. */
struct _SchedEntryDb {
    /** Reference to the first SchedEntry structure. */
    SchedEntry              *head;
    /** Reference to the last SchedEntry structure. */
    SchedEntry              *tail;
    /** Amount of entries. */
    unsigned int            entries;
};


/** Creates a typename for _SchedEntryDb. */
typedef struct _SchedEntryDb SchedEntryDb;


#endif
